package org.ow2.odis;

import junit.framework.TestCase;

import org.ow2.odis.admin.Launch;
import org.ow2.odis.connection.context.Context;
import org.ow2.odis.engine.IProceed;
import org.ow2.odis.exception.StateException;
import org.ow2.odis.node.Node;
import org.ow2.odis.node.NodeManager;
import org.ow2.odis.proceed.ProceedManager;

/**
 *
 * @author mobo7205
 */
public class BasicConnectionTest extends TestCase {

    public BasicConnectionTest(String arg0) {
        super(arg0);
    }

    public BasicConnectionTest() {
    }

    public void bench(String arg,int min) {
        System.out.println("Load");
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, arg);
        System.out.println("Start ");
        int count=0;
        new Thread(lance).start();
        try {
            
            Thread.sleep(10000);
            Node node = NodeManager.getInstance().getNode("Compteur");
            assertNotNull("Node Compteur not created", node);
            Compteur compteur;
            compteur = (Compteur) node.getEngineProceed().getAttribute().getProceedInstance();
            count=compteur.getCount();
            System.out.println("number of msg received by counter :" + count);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
      try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        try {
            Thread.sleep(2000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        if (count < min) {
                fail("not enough message arrive : just " + count + " (" + min + " expected)");
            }
        System.out.println("startStop end");
    }
    public void runOne2One(String config) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu = NodeManager.getInstance().getNode("Simulateur");
        Node nodeCompteur = NodeManager.getInstance().getNode("Compteur");
        
        assertNotNull("Node Compteur not created", nodeCompteur);
        assertNotNull("Node Simulateur not created", nodeSimu);

        IProceed simu = nodeSimu.getEngineProceed().getAttribute().getProceedInstance();
        ProceedManager.getInstance().activeProceed(simu);
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt = nodeCompteur.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        System.out.println("receive " + ((Compteur) compt).getCount() + " msg");
        assertEquals("Error in the number of waited messages", 1, ((Compteur) compt).getCount());
    }

     public void runContextualOne2One(String config,Context context) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu = NodeManager.getInstance().getNode("SimulateurContextuel");
        Node nodeCompteur = NodeManager.getInstance().getNode("Compteur");
        assertNotNull("Node Compteur not created", nodeCompteur);
        assertNotNull("Node SimulateurContextuel not created", nodeSimu);

        SimulateurContextual simu = (SimulateurContextual) nodeSimu.getEngineProceed().getAttribute().getProceedInstance();
        simu.context=context;
        ProceedManager.getInstance().activeProceed(simu);
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt = nodeCompteur.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        System.out.println("receive " + ((Compteur) compt).getCount() + " msg");
        assertEquals("Error in the number of waited messages", 1, ((Compteur) compt).getCount());
    }

    
    public void runTwo2One(String config) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu1 = NodeManager.getInstance().getNode("Simulateur1");
        Node nodeSimu2 = NodeManager.getInstance().getNode("Simulateur2");
        Node nodeCompteur = NodeManager.getInstance().getNode("Compteur");
        assertNotNull("Node Compteur not created", nodeCompteur);
        assertNotNull("Node Simulateur1 not created", nodeSimu1);
        assertNotNull("Node Simulateur2 not created", nodeSimu2);

        IProceed simu;
        simu = nodeSimu1.getEngineProceed().getAttribute().getProceedInstance();
        ProceedManager.getInstance().activeProceed(simu);
        simu = nodeSimu2.getEngineProceed().getAttribute().getProceedInstance();
        ProceedManager.getInstance().activeProceed(simu);
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt = nodeCompteur.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        System.out.println("receive " + ((Compteur) compt).getCount() + " msg");
        assertEquals("Error in the number of waited messages", 2, ((Compteur) compt).getCount());
    }

    public void runOne2TwoAssertDiffusion(String config) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu = NodeManager.getInstance().getNode("Simulateur");
        Node nodeCompteur1 = NodeManager.getInstance().getNode("Compteur1");
        Node nodeCompteur2 = NodeManager.getInstance().getNode("Compteur2");


        IProceed simu;
        simu = nodeSimu.getEngineProceed().getAttribute().getProceedInstance();
        ProceedManager.getInstance().activeProceed(simu);
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt1 = nodeCompteur1.getEngineProceed().getAttribute().getProceedInstance();
        IProceed compt2 = nodeCompteur2.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        System.out.println("receive " + ((Compteur) compt1).getCount() + " msg on compteur 1");
        System.out.println("receive " + ((Compteur) compt2).getCount() + " msg on compteur 2");
        assertEquals("Compteur1 : Error in the number of waited messages", 1, ((Compteur) compt1).getCount());
        assertEquals("Compteur1 : Error in the number of waited messages", 1, ((Compteur) compt2).getCount());
    }

        public void runContextualOne2Two(String config,Context context1,Context context2) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu = NodeManager.getInstance().getNode("SimulateurContextual");
        Node nodeCompteur1 = NodeManager.getInstance().getNode("Compteur1");
        Node nodeCompteur2 = NodeManager.getInstance().getNode("Compteur2");


        SimulateurContextual simu;
        simu = (SimulateurContextual) nodeSimu.getEngineProceed().getAttribute().getProceedInstance();
        simu.context=context1;
        ProceedManager.getInstance().activeProceed(simu);
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        simu.context=context2;
        ProceedManager.getInstance().activeProceed(simu);
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt1 = nodeCompteur1.getEngineProceed().getAttribute().getProceedInstance();
        IProceed compt2 = nodeCompteur2.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        System.out.println("receive " + ((Compteur) compt1).getCount() + " msg on compteur 1");
        System.out.println("receive " + ((Compteur) compt2).getCount() + " msg on compteur 2");
        assertEquals("Compteur1 : Error in the number of waited messages", 1, ((Compteur) compt1).getCount());
        assertEquals("Compteur2 : Error in the number of waited messages", 1, ((Compteur) compt2).getCount());
    }

    public void runOne2Two(String config, Context context1, Context context2) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu = NodeManager.getInstance().getNode("Simulateur");
        Node nodeCompteur1 = NodeManager.getInstance().getNode("Compteur1");
        Node nodeCompteur2 = NodeManager.getInstance().getNode("Compteur2");


        SimulateurContextual simu;
        simu = (SimulateurContextual) nodeSimu.getEngineProceed().getAttribute().getProceedInstance();
        for (int i = 0; i < 10; i++) {
            simu.context = context1;
            ProceedManager.getInstance().activeProceed(simu);
        }
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        for (int i = 0; i < 20; i++) {
            simu.context = context2;
            ProceedManager.getInstance().activeProceed(simu);
        }
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt1 = nodeCompteur1.getEngineProceed().getAttribute().getProceedInstance();
        IProceed compt2 = nodeCompteur2.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        int result1 = ((Compteur) compt1).getCount();
        int result2 = ((Compteur) compt2).getCount();
        System.out.println("receive " + result1 + " msg on compteur 1");
        System.out.println("receive " + result2 + " msg on compteur 2");
        assertEquals("Compteur1 : Error in the number of waited messages", 10, result1);
        assertEquals("Compteur2 : Error in the number of waited messages", 20, result2);
    }

    public void runOne2TwoAssertRepartition(String config) {
        Launch instance = Launch.getInstance();
        LanceThread lance = new LanceThread(instance, config);
        new Thread(lance).start();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        Node nodeSimu = NodeManager.getInstance().getNode("Simulateur");
        Node nodeCompteur1 = NodeManager.getInstance().getNode("Compteur1");
        Node nodeCompteur2 = NodeManager.getInstance().getNode("Compteur2");


        IProceed simu;
        simu = nodeSimu.getEngineProceed().getAttribute().getProceedInstance();
        for (int i = 0; i < 100; i++) {
            ProceedManager.getInstance().activeProceed(simu);
        }
        try {
            Thread.sleep(5000);
        } catch (InterruptedException ex) {
            ex.printStackTrace();
        }
        IProceed compt1 = nodeCompteur1.getEngineProceed().getAttribute().getProceedInstance();
        IProceed compt2 = nodeCompteur2.getEngineProceed().getAttribute().getProceedInstance();
        try {
            instance.stop();
        } catch (StateException e) {
            e.printStackTrace();
        }
        int result1 = ((Compteur) compt1).getCount();
        int result2 = ((Compteur) compt2).getCount();
        System.out.println("receive " + result1 + " msg on compteur 1");
        System.out.println("receive " + result2 + " msg on compteur 2");
        assertTrue("Compteur1 : Error in the number of waited messages", result1 > 0);
        assertTrue("Compteur2 : Error in the number of waited messages", result2 > 0);
        assertEquals("Error in the number of waited messages", 100, (result1 + result2));

    }
}
