package org.ow2.odis.test;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.util.monolog.Monolog;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.odis.engine.FWEvent;
import org.ow2.odis.engine.IProceed;
import org.ow2.odis.testModel.Tension;

/**
 * The Class ProcessGenerateTension.
 */
public class ProcessGenerateTension implements IProceed {
    // ----------------------------------------------------------------------------------------
    // attributes
    // ----------------------------------------------------------------------------------------
    /** The Constant LOGGER. */
    private static final Logger LOGGER = Monolog.initialize().getLogger(ProcessGenerateTension.class.getName());

    /** The j. */
    private static long j = 0;

    /** The consummable classes. */
    private final String[] consummableClasses = {};

    /** The generated classes. */
    private final String[] generatedClasses = { Tension.class.getName() };

    /** The nbr tension. */
    private int nbrTension = 10;

    // ----------------------------------------------------------------------------------------
    // methodes
    // ----------------------------------------------------------------------------------------
    /**
     * Proceed.
     * @param obj the obj
     * @return the list
     * @see com.francetelecom.odis.component.engine.IProceed#proceed(java.lang.Object)
     */
    public List proceed(Object obj) {
        LOGGER.log(BasicLevel.DEBUG, "Generate " + nbrTension + " new tension");
        List result = new ArrayList();
        for (int i = 0; i < nbrTension; i++) {
            j++;
            Tension t = new Tension();
            t.setId(j);
            t.setTime(System.currentTimeMillis());
            t.setTelephone("O445454557");
            t.setValue(456);
            LOGGER.log(BasicLevel.INFO, "   => tension (" + i + ")" + t);
            result.add(t);
        }
        return result;
    }

    /**
     * Init.
     * @param value the value
     * @return true, if init
     * @see com.francetelecom.odis.component.engine.IProceed#init(java.lang.String)
     */
    public boolean init(String value) {
        try {
            nbrTension = Integer.parseInt(value);
        } catch (NumberFormatException e) {
            LOGGER.log(BasicLevel.INFO, "param proceed invalid : number of tension set by default ");
            nbrTension = 10;
        }
        return true;
    }

    /**
     * Close.
     * @see com.francetelecom.odis.component.engine.IProceed#close()
     */
    public void close() {
    }

    /**
     * Notify FW event.
     * @param event the event
     * @see com.francetelecom.odis.component.engine.IProceed#notifyFWEvent(com.francetelecom.odis.component.engine.FWEvent)
     */
    public void notifyFWEvent(FWEvent event) {
    }

    /**
     * Gets the consumable classes.
     * @return the consumable classes
     */
    public String[] getConsumableClasses() {
        return consummableClasses;
    }

    /**
     * Gets the generate classes.
     * @return the generate classes
     */
    public String[] getGenerateClasses() {
        return generatedClasses;
    }
}
