package org.ow2.odis.test;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.util.monolog.Monolog;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.odis.engine.FWEvent;
import org.ow2.odis.engine.IProceed;
import org.ow2.odis.testModel.Tension;
import org.ow2.odis.testModel.TensionOdd;
import org.ow2.odis.testModel.TensionPeer;

/**
 * The Class ProcessRouteTension.
 */
public class ProcessRouteTension implements IProceed {
    // ----------------------------------------------------------------------------------------
    // attributes
    // ----------------------------------------------------------------------------------------
    /** The Constant LOGGER. */
    private final static Logger LOGGER = Monolog.initialize().getLogger(ProcessRouteTension.class.getName());

    /** The consummable classes. */
    private final String[] consummableClasses = { TensionOdd.class.getName(), TensionPeer.class.getName() };

    /** The generated classes. */
    private final String[] generatedClasses = { Tension.class.getName() };

    // ----------------------------------------------------------------------------------------
    // methodes
    // ----------------------------------------------------------------------------------------
    /**
     * Proceed.
     * @param obj the obj
     * @return the list
     * @see com.francetelecom.odis.component.engine.IProceed#proceed(java.lang.Object)
     */
    public List proceed(Object obj) {
        List result = new ArrayList();
        // logger.log(BasicLevel.DEBUG, "Route element");
        Tension t = (Tension) obj;
        // logger.log(BasicLevel.INFO, " <= get tension: " + t);
        if (obj.getClass().getName() == "com.francetelecom.odis.test.TensionOdd") {
            if ((t.getId() % 2) != 1) {
                LOGGER.log(BasicLevel.ERROR, t.getId() + " is not Odd: " + t.getTelephone());
                return null;
            }
        }
        if (obj.getClass().getName() == "com.francetelecom.odis.test.TensionPeer") {
            if ((t.getId() % 2) != 0) {
                LOGGER.log(BasicLevel.ERROR, t.getId() + " is not Peer: " + t.getTelephone());
                return null;
            }
        }
        result.add(obj);
        return result;
    }

    /**
     * Init.
     * @param value the value
     * @return true, if init
     * @see com.francetelecom.odis.component.engine.IProceed#init(java.lang.String)
     */
    public boolean init(String value) {
        return true;
    }

    /**
     * Close.
     * @see com.francetelecom.odis.component.engine.IProceed#close()
     */
    public void close() {
    }

    /**
     * Notify FW event.
     * @param event the event
     * @see com.francetelecom.odis.component.engine.IProceed#notifyFWEvent(com.francetelecom.odis.component.engine.FWEvent)
     */
    public void notifyFWEvent(FWEvent event) {
    }

    /**
     * Gets the consumable classes.
     * @return the consumable classes
     */
    public String[] getConsumableClasses() {
        return consummableClasses;
    }

    /**
     * Gets the generate classes.
     * @return the generate classes
     */
    public String[] getGenerateClasses() {
        return generatedClasses;
    }
}
