package org.ow2.odis.testModel;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;

import org.objectweb.util.monolog.Monolog;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.odis.decoder.IDecoder;
import org.ow2.odis.encoder.IEncoder;
import org.ow2.odis.util.CodingDecoding;
import org.ow2.odis.util.IntegerModif;

/**
 * The Class TensionEncoderDecoderPeer.
 */
public class TensionEncoderDecoderPeer implements IEncoder, IDecoder {
    // ----------------------------------------------------------------------------------------
    // attributes
    // ----------------------------------------------------------------------------------------
    /** The Constant LOGGER. */
    private final static Logger LOGGER = Monolog.initialize().getLogger(TensionEncoderDecoderPeer.class.getName());

    // ----------------------------------------------------------------------------------------
    // methodes
    // ----------------------------------------------------------------------------------------
    /**
     * transforme an object to a byte array.
     * @param object the object
     * @return the byte[]
     */
    public byte[] encode(Object object) {
        byte[] result = null;
        TensionPeer tension = (TensionPeer) object;
        LOGGER.log(BasicLevel.DEBUG, "encode tension" + tension);
        byte[][] value = new byte[4][];
        try {
            value[0] = CodingDecoding.longTo8Bytes(tension.getId());
            value[1] = CodingDecoding.longTo8Bytes(tension.getTime());
            value[2] = CodingDecoding.stringToBytes(tension.getTelephone());
            value[3] = CodingDecoding.intTo4Bytes(tension.getValue());
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        result = CodingDecoding.getLinearByte(value);
        LOGGER.log(BasicLevel.DEBUG, "encode tension size " + result.length);
        return result;
    }

    /**
     * decode the msg from byte array representing a list of tension objects witch have been serialized by encode function.
     * @param msg the msg
     * @return the list
     */
    public List decode(byte[] msg) {
        if (msg == null) {
            LOGGER.log(BasicLevel.ERROR, "message to decode is null");
            return null;
        }
        IntegerModif cursor = new IntegerModif(0);
        TensionPeer tension = null;
        List result = new ArrayList();
        try {
            while (cursor.intValue() < msg.length) {
                LOGGER.log(BasicLevel.DEBUG, "Cursor " + cursor.intValue() + " size buffer " + msg.length);
                tension = new TensionPeer();
                tension.setId(CodingDecoding.getLongFrom8bytes(msg, cursor));
                tension.setTime(CodingDecoding.getLongFrom8bytes(msg, cursor));
                tension.setTelephone(CodingDecoding.getString(msg, cursor));
                tension.setValue(CodingDecoding.getIntFrom4bytes(msg, cursor));
                LOGGER.log(BasicLevel.DEBUG, "decode tension " + tension);
                result.add(tension);
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        return result;
    }

    /**
     * Gets the type.
     * @return the type
     * @see com.francetelecom.odis.component.encoder.IEncoder#getType()
     */
    public String getType() {
        return TensionPeer.class.getName();
    }
}
